==> annotate-workspace-layout-1.0.0.tgz: package/HeaderButton/index.js <==
import React from "react";
import Button from "@mui/material/Button";
import { styled } from "@mui/styles";
import { createTheme, ThemeProvider } from "@mui/material/styles";
import { useIconDictionary } from "../icon-dictionary.js";
import { iconMapping } from "../icon-mapping.js";
import { colors } from "@mui/material";
var theme = createTheme();
var defaultNameIconMapping = iconMapping;

var getIcon = function getIcon(name, customIconMapping) {
  var Icon = customIconMapping[name.toLowerCase()] || defaultNameIconMapping[name.toLowerCase()] || defaultNameIconMapping.help;
  return /*#__PURE__*/React.createElement(Icon, null);
};

var StyledButton = styled(Button)(function (_ref) {
  var theme = _ref.theme;
  return {
    textTransform: "none",
    width: 60,
    paddingTop: 8,
    paddingBottom: 4,
    marginLeft: 1,
    marginRight: 1
  };
});
var ButtonInnerContent = styled("div")(function (_ref2) {
  var theme = _ref2.theme;
  return {
    display: "flex",
    flexDirection: "column"
  };
});
var IconContainer = styled("div")(function () {
  return {
    color: colors.grey[700],
    height: 32,
    paddingTop: 8,
    "& .MuiSvgIcon-root": {
      width: 18,
      height: 18
    }
  };
});
var IconContainerHidden = styled("div")(function () {
  return {
    color: colors.grey[700],
    height: 20,
    paddingTop: 0,
    "& .MuiSvgIcon-root": {
      width: 18,
      height: 18
    }
  };
});
var Text = styled("div")(function (_ref3) {
  var theme = _ref3.theme;
  return {
    fontWeight: "bold",
    fontSize: 11,
    color: colors.grey[800],
    display: "flex",
    alignItems: "center",
    lineHeight: 1,
    justifyContent: "center"
  };
});
export var HeaderButton = function HeaderButton(_ref4) {
  var name = _ref4.name,
      icon = _ref4.icon,
      disabled = _ref4.disabled,
      onClick = _ref4.onClick,
      _ref4$hideText = _ref4.hideText,
      hideText = _ref4$hideText === void 0 ? false : _ref4$hideText;
  var customIconMapping = useIconDictionary();
  return /*#__PURE__*/React.createElement(ThemeProvider, {
    theme: theme
  }, /*#__PURE__*/React.createElement(StyledButton, {
    onClick: onClick,
    disabled: disabled
  }, /*#__PURE__*/React.createElement(ButtonInnerContent, null, hideText ? /*#__PURE__*/React.createElement(IconContainer, null, icon || getIcon(name, customIconMapping)) : /*#__PURE__*/React.createElement(IconContainerHidden, null, icon || getIcon(name, customIconMapping)), !hideText && /*#__PURE__*/React.createElement(Text, null, /*#__PURE__*/React.createElement("div", null, name)))));
};
export default HeaderButton;

==> annotate-workspace-layout-1.0.1.tgz: package/HeaderButton/index.js <==
import React from "react";
import Button from "@mui/material/Button";
import { styled } from "@mui/styles";
import { createTheme, ThemeProvider } from "@mui/material/styles";
import { useIconDictionary } from "../icon-dictionary.js";
import { iconMapping } from "../icon-mapping.js";
import { colors } from "@mui/material";
import { height, width } from "@mui/system";
var theme = createTheme();
var defaultNameIconMapping = iconMapping;

var getIcon = function getIcon(name, customIconMapping) {
  var Icon = customIconMapping[name.toLowerCase()] || defaultNameIconMapping[name.toLowerCase()] || defaultNameIconMapping.help;
  return /*#__PURE__*/React.createElement(Icon, null);
};

var StyledButton = styled(Button)(function (_ref) {
  var theme = _ref.theme;
  return {
    textTransform: "none",
    paddingTop: 8,
    paddingBottom: 4,
    "&[type='button']": {
      padding: "7px 14px",
      margin: "0 1px",
      "&:not(:last-child)": {
        position: "relative",
        "&::after": {
          content: '""',
          position: "absolute",
          width: "1px",
          height: "70%",
          background: "#A4A4AF",
          right: "0",
          top: "50%",
          transform: "translateY(-50%)"
        }
      }
    }
  };
});
var ButtonInnerContent = styled("div")(function (_ref2) {
  var theme = _ref2.theme;
  return {
    display: "flex"
  };
});
var IconContainer = styled("div")(function () {
  return {
    color: colors.grey[700],
    height: 32,
    paddingTop: 8,
    "& .MuiSvgIcon-root": {
      width: 18,
      height: 18
    }
  };
});
var IconContainerHidden = styled("div")(function () {
  return {
    color: colors.grey[700],
    height: 20,
    paddingTop: 0,
    "& .MuiSvgIcon-root": {
      width: 18,
      height: 18
    }
  };
});
var Text = styled("div")(function (_ref3) {
  var theme = _ref3.theme;
  return {
    fontWeight: "bold",
    fontSize: 11,
    color: colors.grey[800],
    display: "flex",
    alignItems: "center",
    lineHeight: 1,
    justifyContent: "center"
  };
});
export var HeaderButton = function HeaderButton(_ref4) {
  var name = _ref4.name,
      icon = _ref4.icon,
      disabled = _ref4.disabled,
      onClick = _ref4.onClick,
      _ref4$hideText = _ref4.hideText,
      hideText = _ref4$hideText === void 0 ? false : _ref4$hideText,
      _ref4$iconPos = _ref4.iconPos,
      iconPos = _ref4$iconPos === void 0 ? "left" : _ref4$iconPos;
  var customIconMapping = useIconDictionary();
  var btnIcon = hideText ? /*#__PURE__*/React.createElement(IconContainer, null, icon || getIcon(name, customIconMapping)) : /*#__PURE__*/React.createElement(IconContainerHidden, null, icon || getIcon(name, customIconMapping));
  return /*#__PURE__*/React.createElement(ThemeProvider, {
    theme: theme
  }, /*#__PURE__*/React.createElement(StyledButton, {
    onClick: onClick,
    disabled: disabled
  }, /*#__PURE__*/React.createElement(ButtonInnerContent, null, iconPos === "left" && btnIcon, !hideText && /*#__PURE__*/React.createElement(Text, null, /*#__PURE__*/React.createElement("div", null, name)), iconPos === "right" && btnIcon)));
};
export default HeaderButton;
